@@ -99,13 +99,14 @@ void BatchRenamer::processFiles( ProgressDialog* p, QObject* object )
         parseSubdirs( &m_files[i] );
         // TODO: DOM 
         // ESCAPE HERE
-        
+   
         m_files[i].src.name = BatchRenamer::buildFilename( &m_files[i].src, true );
-        m_files[i].dst.name = BatchRenamer::buildFilename( &m_files[i].dst, true );
 
         // Let's run the plugins that change the final filename,
         // i.e the encodingsplugin
         m_files[i].dst.name = parsePlugins( i, m_files[i].dst.name, TYPE_FINAL_FILENAME );
+
+        m_files[i].dst.name = BatchRenamer::buildFilename( &m_files[i].dst, true );
                 
         /*
          * take care of renamed directories and
@@ -216,15 +217,14 @@ void BatchRenamer::createPreview( QListView* list )
 
         bool modified = applyManualChanges( i );
 
+
         QString sname = BatchRenamer::buildFilename( &m_files[i].src, false );
+
+        // Let's run the plugins that change the final filename,
+        // i.e the encodingsplugin
+        m_files[i].dst.name = parsePlugins( i, m_files[i].dst.name, TYPE_FINAL_FILENAME );
         QString dname = BatchRenamer::buildFilename( &m_files[i].dst, false );
         
-        // Let's run the plugins that change the final filename,
-        // i.e the encodingsplugin
-        // Let's run the plugins that change the final filename,
-        // i.e the encodingsplugin
-        dname = parsePlugins( i, dname, TYPE_FINAL_FILENAME );
-        
         item1 = new KMyListViewItem( modified, list, item1, sname, dname );
     }
 }
@@ -389,6 +389,7 @@ QString & BatchRenamer::doEscape( QString & text, bool filename )
         BatchRenamer::escape( text, "/", QChar( 60008 ) );
         BatchRenamer::escape( text, "{", QChar( 60009 ) );        
         BatchRenamer::escape( text, "}", QChar( 60010 ) );        
+        BatchRenamer::escape( text, "*", QChar( 60011 ) );        
     } else {
         BatchRenamer::escape( text, "\\&", QChar( 60000 ) );
         BatchRenamer::escape( text, "\\$", QChar( 60001 ) );
@@ -399,7 +400,8 @@ QString & BatchRenamer::doEscape( QString & text, bool filename )
         BatchRenamer::escape( text, "\\\\", QChar( 60007 ) ); 
         BatchRenamer::escape( text, "\\/", QChar( 60008 ) );
         BatchRenamer::escape( text, "\\{", QChar( 60009 ) );        
-        BatchRenamer::escape( text, "\\}", QChar( 60010 ) );        
+        BatchRenamer::escape( text, "\\}", QChar( 60010 ) );      
+        BatchRenamer::escape( text, "\\*", QChar( 60011 ) );          
     }
 
     return text;
@@ -418,8 +420,9 @@ QString & BatchRenamer::unEscape( QString & text )
     // a /. So I use %252f, at least konqui displays it correctly
     // this was needed, so that plugins that return a slash do not cause errors
     BatchRenamer::escape( text, QChar( 60008 ), "%2f" );
-    BatchRenamer::escape( text, QChar( 60009 ), "\\{" );        
-    BatchRenamer::escape( text, QChar( 60010 ), "\\}" );        
+    BatchRenamer::escape( text, QChar( 60009 ), "{" );        
+    BatchRenamer::escape( text, QChar( 60010 ), "}" );        
+    BatchRenamer::escape( text, QChar( 60011 ), "*" );
 
     return text;
 }
@@ -607,10 +610,14 @@ QString BatchRenamer::processToken( QString token, QString oldname, int i )
         return tmp;
         
     Plugin* p = plug->findPlugin( token );
-    if( p ) {
+    if( p )
+    {
         tmp = p->processFile( this, i, token, TYPE_BRACKET );
         if( !tmp.isNull() )
+        {
+            doEscape( tmp );
             return tmp;
+        }
     }
 
     /*
@@ -683,7 +690,8 @@ QString BatchRenamer::findToken( QString oldname, QString token, int i )
             break;
     }
 
-    return doEscape( token );
+    doEscape( token );
+    return token;
 }
 
 QString BatchRenamer::findPartStrings( QString oldname, QString token )
@@ -803,7 +811,8 @@ QString BatchRenamer::findReplace( QString text )
 
 QString BatchRenamer::doReplace( QString text, QString find, QString replace, bool reg )
 {
-    if( !reg ) {
+    if( !reg ) 
+    {
 #if QT_VERSION >= 0x030100
         // we use the escaped text here because the user might want 
         // to find a "&" and replace it
@@ -820,7 +829,9 @@ QString BatchRenamer::doReplace( QString text, QString find, QString replace, bo
             }
         } while( pos >= 0 );
 #endif
-    } else {
+    } 
+    else
+    {
 #if QT_VERSION >= 0x030100    
         // no doEscape() here for the regexp, because it would destroy our regular expression
         // other wise we will not find stuff like $, [ in the text 
