@@ -98,7 +98,7 @@ KRenameImpl::KRenameImpl( QWidget* p, KMenuBar* m, QPushButton* finish )
     plugin = PluginLoader::instance();
     helpDialogData = new HelpDialogData();
     // Maybe parent instead of 0 but might crash when switching from wizard to tab mode
-    helpDialog = new HelpDialog( helpDialogData, 0, false );
+    helpDialog = new HelpDialog( helpDialogData, NULL, NULL, false );
 
     m_switching = false;
     
@@ -111,7 +111,7 @@ KRenameImpl::~KRenameImpl()
     delete helpDialog;
 }
 
-bool KRenameImpl::noRealTimePreview = false;
+int KRenameImpl::numRealTimePreview = -1;
 
 void KRenameImpl::setup( bool wizardmode )
 {
@@ -211,10 +211,10 @@ void KRenameImpl::parseCommandline()
         ProfileManager::loadProfile( QString( templ ), this );
     }
 
-    if( !args->isSet( "preview" ) )
-        noRealTimePreview = true;
+    if( !args->isSet( "previewitems" ) )
+        numRealTimePreview = -1;
     else
-        noRealTimePreview = false;
+        numRealTimePreview = QString( args->getOption( "previewitems" ) ).toInt();
 
     templ = args->getOption( "template" );
     if( !templ.isEmpty() )
@@ -441,7 +441,7 @@ void KRenameImpl::setupPage2()
     optionLink = new QRadioButton( groupOptions );
     optionLink->setText( i18n("Create symbolic &links in destination directory") );
     
-    dirname = new KMyHistoryCombo( groupOptions, "Path" );
+    dirname = new KMyHistoryCombo( false, groupOptions, "Path" );
     urlrequester = new KURLRequester( dirname, groupOptions );
     urlrequester->setMode( KFile::Directory | KFile::ExistingOnly );
     
@@ -548,13 +548,13 @@ void KRenameImpl::setupFileTab1()
     labelTemplate = new QLabel( tab );
     labelTemplate->setText( i18n( "&Template:" ) );
 
-    filename = new KMyHistoryCombo( tab, "Template" );
+    filename = new KMyHistoryCombo( true, tab, "Template" );
     labelTemplate->setBuddy( filename );
 
     QLabel* labelDot = new QLabel( tab );
     labelDot->setText("<b>.</b>");
 
-    extemplate = new KMyHistoryCombo( tab, "ExTemplate" );
+    extemplate = new KMyHistoryCombo( true, tab, "ExTemplate" );
     extemplate->setEnabled( FALSE );
 
     buttonHelp = new KPushButton( i18n("&Functions..."), tab );
@@ -659,13 +659,13 @@ void KRenameImpl::setupFileTab2()
         
     QLabel* l = new QLabel( i18n("&Prefix:"), grid );
     comboKRenamePrefix = new KComboBox( false, grid );
-    comboPrefix = new KMyHistoryCombo( grid, "comboPrefix" );   
+    comboPrefix = new KMyHistoryCombo( true, grid, "comboPrefix" );   
     buttonEasy1 = new KPushButton( grid );
     l->setBuddy( comboPrefix );
     
     l = new QLabel( i18n("&Suffix:"), grid );
     comboKRenameSuffix = new KComboBox( false, grid, "comboSuffix"  );
-    comboSuffix = new KMyHistoryCombo( grid );
+    comboSuffix = new KMyHistoryCombo( true, grid );
     buttonEasy2 = new KPushButton( grid );
     l->setBuddy( comboSuffix );
 
@@ -681,7 +681,7 @@ void KRenameImpl::setupFileTab2()
     comboKRenameFilename->insertItem( i18n("Custom name") );
     l->setBuddy( comboKRenameFilename );
     
-    comboCustom = new KMyHistoryCombo( grid, "comboCustom" );
+    comboCustom = new KMyHistoryCombo( true, grid, "comboCustom" );
     buttonEasy3 = new KPushButton( grid );
              
     l = new QLabel( i18n("&Extension:"), grid );
@@ -691,7 +691,7 @@ void KRenameImpl::setupFileTab2()
     comboKRenameExtension->insertItem( i18n("Custom extension") );
     l->setBuddy( comboKRenameExtension );
     
-    comboCustomExtension = new KMyHistoryCombo( grid, "comboCustomExtension" );
+    comboCustomExtension = new KMyHistoryCombo( true, grid, "comboCustomExtension" );
     buttonEasy4 = new KPushButton( grid );
     
     QVBox* rightBox = new QVBox( tab );
@@ -899,6 +899,7 @@ void KRenameImpl::setupTab1()
 
             (*it)->check = new QCheckBox( i18n("&Use this plugin"), parent );
             connect( (*it)->check, SIGNAL( clicked() ), this, SLOT( pluginHelpChanged() ) );
+            connect( (*it)->plugin, SIGNAL( previewChanged() ), this, SLOT( updatePreview() ) );
             Layout->addWidget( (*it)->check );
             (*it)->plugin->drawInterface( g, gLayout );
 
@@ -1082,10 +1083,12 @@ void KRenameImpl::updateCount()
     updateDots();
 }
 
-void KRenameImpl::fillStructures( BatchRenamer* b )
+void KRenameImpl::fillStructures( BatchRenamer* b, bool preview )
 {
     QValueList<data> f;
-    for( unsigned int i = 0; i < fileList->count(); i++) {
+    unsigned int max = (preview && KRenameImpl::numRealTimePreview > -1 ? KRenameImpl::numRealTimePreview : fileList->count());
+
+    for( unsigned int i = 0; i < max; i++) {
         KURL url = fileList->url( i );
         QFileInfo fi( url.path() );
         
@@ -1189,7 +1192,7 @@ bool KRenameImpl::setupBatchRenamer( BatchRenamer* b, bool preview )
         b->setMode( currentRenameMode() );
     }
 
-    fillStructures( b );
+    fillStructures( b, preview );
     return true;
 }
 
@@ -1215,9 +1218,6 @@ void KRenameImpl::updatePreview()
     else
         buttonNumber->setEnabled( false );
 
-    if( noRealTimePreview )
-        return;
-    
     if( filename->isEmpty() && extemplate->isEmpty() && !checkExtension->isChecked() )
         return;
 
