@@ -132,7 +132,7 @@ Plugin* PluginLoader::findPlugin( const QString & token )
     QMap<QString,Plugin*>::Iterator it;
     for ( it = m_bracket_map.begin(); it != m_bracket_map.end(); ++it ) 
     {
-        if( QRegExp( it.key() ).exactMatch( lower ) )
+        if( it.key() == lower )
         {
             m_bracket_cache.insert( lower, it.data(), true );
             if( m_bracket_cache.count() > BRACKET_CACHE_COUNT )
@@ -141,6 +141,12 @@ Plugin* PluginLoader::findPlugin( const QString & token )
             return it.data();
         }
     }
+
+    // add typos to the cache, too:
+    // So that we find immediately that this key is not supported.
+    m_bracket_cache.insert( lower, NULL, true );
+    if( m_bracket_cache.count() > BRACKET_CACHE_COUNT )
+        m_bracket_cache.remove( m_bracket_cache.begin() );
         
     return NULL;
 }
